<?php

namespace Drupal\drucash\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;

/**
 * List builder for the accounts.
 */
class AccountListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header = [];
    $header['id'] = $this->t('Id');
    $header['name'] = $this->t('Name');
    $header['type'] = $this->t('Type');
    $header['description'] = $this->t('Description');
    $header['balance'] = $this->t('Balance');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\drucash\Entity\AccountInterface $entity */
    $row = [];
    $row['id'] = $entity->id();
    $row['name'] = $entity->getName();
    $row['type'] = $entity->getTypeLabel();
    $row['description'] = $entity->getDescription();
    $row['balance'] = $entity->getBalance();
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getOperations(EntityInterface $entity): array {

    $operations = [];
    $operations['ledger'] = [
      'title' => $this->t('Ledger'),
      'weight' => 1.0,
      'url' => Url::fromRoute('drucash.account_ledger', ['drucash_account' => $entity->id()]),
    ];

    return $operations + parent::getOperations($entity);
  }

}
