<?php

namespace Drupal\drucash\Entity;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * The account entity interface.
 */
interface AccountInterface extends ContentEntityInterface {

  /**
   * Get the account name.
   */
  public function getName();

  /**
   * Get the account description.
   */
  public function getDescription();

  /**
   * Get the account type.
   */
  public function getType();

  /**
   * Get the account type label.
   */
  public function getTypeLabel();

  /**
   * Get the account children.
   */
  public function getChildren();

  /**
   * Gets the current account balance.
   *
   * @return float
   *   The account current balance.
   */
  public function getBalance(): float;

  /**
   * Set the account name.
   */
  public function setName(string $name);

  /**
   * Set the account description.
   */
  public function setDescription(string $description);

  /**
   * Set the account type.
   */
  public function setType(string $type);

  /**
   * Add a children account.
   */
  public function addChildren(AccountInterface $child);

  /**
   * Remove a children account.
   */
  public function removeChildren(AccountInterface $child);

}
